@@ -1,6 +1,6 @@
-/*
+/* 
     SuperCat - The Super Cat Colorizer
-    Copyright (C) 2007-2020 - Mark P. Anderson, Thomas G. Anderson
+    Copyright (C) 2007-2022 - Thomas G Anderson
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -114,9 +114,9 @@ help ()
 void
 version ()
 {
-    printf ("spc (SuperCat Colorizer) Version %s January 1, 2020\n", VERSION);
+    printf ("spc (SuperCat Colorizer) Version %s January 1, 2022\n", VERSION);
     puts   ("");
-    puts   ("Copyright (C) 2007-2020 - Mark P. Anderson, Thomas G. Anderson");
+    puts   ("Copyright (C) 2007-2022 - Thomas G Anderson");
     puts   ("");
     puts   ("This is free software, see the source for copying conditions.");
     puts   ("There is NO warranty not even for MERCHANTABILITY or FITNESS");
@@ -212,7 +212,7 @@ option_E (char *str, char *cmd)
     if (!Fp) Fp = tmpfile ();
 
     if ( (strlen (str) < 11) || (str [3] != ',') || (str [5] != ',') || (str [7] != ',' || (str [9] != ',') ) ) {
-        printf ("%s invalid option string, format is \"color,att,num,typ,string|(RE)\"\n", cmd);
+        printf ("%s invalid option string, format is \"color,attribute,count,type,string|(RE)\"\n", cmd);
         exit (-1);
     }
     str [3] = 0;
@@ -229,7 +229,7 @@ option_E (char *str, char *cmd)
         exit (-1);
     }
     if (number_lookup (str [6]) == -1) {
-        printf ("%s invalid option string number (%c), use: 0-9\n", cmd, str [6]);
+        printf ("%s invalid option string count (%c), use: 0-9\n", cmd, str [6]);
         exit (-1);
     }
     if (patype_lookup (str [8]) == -1) {
@@ -291,7 +291,7 @@ options (int ac, char **av)
           case 'n': opt_line_number = 1; break;
           case 'r': opt_reverse = 1; break;
           case 'R': opt_nohomerc = 1; break;
-          case 'S': sysdir (); break;
+          case 'S': sysdir (); break; 
           case 'v': version (); break;
           case 'w': opt_webpage = 1; break;
 
@@ -414,7 +414,7 @@ options (int ac, char **av)
                 *p++ = 0;
             else
                 p = av [++i];
-
+              
             if (!p || !*p) err_quit ("--config-dir missing parameter");
 
             opt_directory = malloc (strlen (p)+1);
@@ -455,7 +455,7 @@ options (int ac, char **av)
                 *p++ = 0;
             else
                 p = av [++i];
-
+              
             if (!p || !*p) err_quit ("--type missing parameter");
 
             opt_type = malloc (strlen (p)+1);
@@ -715,7 +715,7 @@ attrib_lookup_or_exit (char chr)
       err_quit ("unknown attribute %c at line number %d", chr, inp_lineno);
 
     return (att);
-}
+}      
 
 int
 patype_lookup (char chr)
@@ -740,7 +740,7 @@ patype_lookup_or_exit (char chr)
       err_quit ("unknown pattern type %c at line number %d", chr, inp_lineno);
 
     return (typ);
-}
+}      
 
 int
 colour_str (spc_t *spc, char *string, char *aryidx, int n)
@@ -838,8 +838,8 @@ colour_rex (spc_t *spc, char *string, char *aryidx, int n)
              *  characters so the string stays the same size.
              *
              *  UNIXTM1 : t : MMDDHHMMSS
-             *  UNIXTM2 : T : YYMMDDHHMM
-             *  UNIXTM3 : u :   HH:MM:SS
+             *  UNIXTM2 : T : YYMMDDHHMM 
+             *  UNIXTM3 : u :   HH:MM:SS 
              *  UNIXTM4 : U : YYYY:MM:DD
              */
             if (spc->patype == PATYPE_UNIXTM1) {
@@ -1117,6 +1117,9 @@ create_rex (FILE *fp)
      *  the strings are just stored.
      */
     while (fgets (buffer, sizeof (buffer), fp)) {
+        if (Spn >= NREGEX)
+            err_quit ("too many config file entries, %d max", NREGEX);
+
         n = strlen (buffer);
         if (n == BUFFER)
             err_quit ("line too long: %s", buffer);
@@ -1141,7 +1144,7 @@ create_rex (FILE *fp)
         spc->attrib = attrib_lookup_or_exit ( buffer [COLUMN_ATTRIB]);
         spc->number = number_lookup_or_exit ( buffer [COLUMN_NUMBER]);
         spc->patype = patype_lookup_or_exit ( buffer [COLUMN_PATYPE]);
-
+        
         spc->htmrgb = malloc (strlen (&buffer [COLUMN_HTMRGB]) + 1);
         strcpy (spc->htmrgb,&buffer [COLUMN_HTMRGB]);
         spc->htmlen = strlen (spc->htmrgb);
